==> jackrabbit-oak-1.6.23-src.zip: jackrabbit-oak-1.6.23/oak-doc/src/site/markdown/architecture/overview.md <==
<!--
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
  -->

Oak - The big picture
--------------------------------------------------------------------------------

TODO: Explain concepts: MVCC, Oak modules and plugins, key APIs, ...

![The big picture](big-picture.png?raw=true)

## Main Concepts

* [Node State Model](nodestate.html)
* [Transactional Model](transactional-model.html)

## The APIs

* [JCR](http://www.day.com/specs/jcr/2.0/index.html)
* [Oak API](../oak_api/overview.html)
* [NodeStore API](../nodestore/overview.html)

## Readmes

* [Oak](https://github.com/apache/jackrabbit-oak/blob/trunk/README.md)
* [Oak core](https://github.com/apache/jackrabbit-oak/blob/trunk/oak-core/README.md)
* [Oak run](https://github.com/apache/jackrabbit-oak/blob/trunk/oak-run/README.md)

==> jackrabbit-oak-1.22.12-src.zip: jackrabbit-oak-1.22.12/oak-doc/src/site/markdown/architecture/overview.md <==
<!--
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
  -->

Oak - The big picture
--------------------------------------------------------------------------------

TODO: Explain concepts: MVCC, Oak modules and plugins, key APIs, ...

![The big picture](big-picture.png?raw=true)

## Main Concepts

* [Node State Model](nodestate.html)
* [Transactional Model](transactional-model.html)

## The APIs

* [JCR](https://docs.adobe.com/docs/en/spec/javax.jcr/javadocs/jcr-2.0/index.html)
* [Oak API](../oak_api/overview.html)
* [NodeStore API](../nodestore/overview.html)

## Readmes

* [Oak](https://github.com/apache/jackrabbit-oak/blob/trunk/README.md)
* [Oak core](https://github.com/apache/jackrabbit-oak/blob/trunk/oak-core/README.md)
* [Oak run](https://github.com/apache/jackrabbit-oak/blob/trunk/oak-run/README.md)
